@@ -1,5 +1,5 @@
 spec_opts_chunk <- function(results_folding = c("none", "show", "hide")) {
-  options = list()
+  options <- list(minidown_hook = TRUE)
 
   results_folding <- match.arg(results_folding)
   if (results_folding != "none") {
